@@ -108,9 +108,9 @@ struct _SummaryView
 	GtkWidget *toggle_search;
 	GtkWidget *quick_search_pixmap;
 	GtkWidget *popupmenu;
+	GtkWidget *headerpopupmenu;
 	GtkWidget *colorlabel_menu;
 	GtkWidget *tags_menu;
-
 	GtkWidget *window;
 
 	GtkCMCTreeNode *selected;
@@ -169,18 +169,27 @@ private:
 
 	GtkTargetList *target_list; /* DnD */
 
-	// folders with matches for recursive quicksearch queries
+	/* folders with matches for recursive quicksearch queries */
 	GSList *recursive_matched_folders;
 	FolderItem *search_root_folder;
 
 	guint mark_as_read_timeout_tag;
+
+	/* A flag to indicate to header popup menuitem handlers that
+	 * they should not do anything, because the menu items are
+	 * being set up prior to the popup menu being displayed. */
+	gboolean header_menu_lock;
+
+	GtkActionGroup *action_group;
+	GtkUIManager *ui_manager;
 };
 
 SummaryView	*summary_create(MainWindow *mainwin);
 void summaryview_destroy(SummaryView *summaryview);
 void summary_init		  (SummaryView		*summaryview);
 gboolean summary_show		  (SummaryView		*summaryview,
-				   FolderItem		*fitem);
+				   FolderItem		*fitem,
+				   gboolean		 avoid_refresh);
 void summary_clear_list		  (SummaryView		*summaryview);
 void summary_clear_all		  (SummaryView		*summaryview);
 
@@ -333,4 +342,6 @@ void summary_relayout(SummaryView *summaryview);
 void summary_update_unread(SummaryView *summaryview, FolderItem *removed_item);
 gboolean summary_is_list(SummaryView *summaryview);
 gboolean summaryview_search_root_progress(gpointer data, guint at, guint matched, guint total);
+gboolean summary_is_opened_message_selected(SummaryView *summaryview);
+gboolean summary_has_opened_message(SummaryView *summaryview);
 #endif /* __SUMMARY_H__ */
